Learn R Programming

rportfolio (version 0.0.3)

alpha.capm: CAPM Alpha

Description

Calculates the portfolio alpha

Usage

alpha.capm(R1, R2)

Arguments

R1

Portfolio return as xts

R2

Benchmark Returns

Value

Returns the alpha of the portfolio

Details

Alpha is a term used in investing to describe a strategy's ability to beat the market, or it's "edge." Alpha is thus also often referred to as <U+201C>excess return<U+201D> or <U+201C>abnormal rate of return,<U+201D> which refers to the idea that markets are efficient, and so there is no way to systematically earn returns that exceed the broad market as a whole.

Examples

Run this code
# NOT RUN {
alpha.capm(funds$ret1, funds$rfr)
# }

Run the code above in your browser using DataLab