Learn R Programming

rportfolio (version 0.0.3)

jenson.alpha: Jenson's Alpha

Description

Calculates the Jenson's Alpha of the security

Usage

jenson.alpha(R1, R2, rf = 0)

Arguments

R1

Portfolio Return

R2

Benchmark Return

rf

Risk Free Rate of Return, Default: 0

Value

The Jensen's measure, or Jensen's alpha, is a risk-adjusted performance measure that represents the average return on a portfolio or investment, above or below that predicted by the capital asset pricing model (CAPM), given the portfolio's or investment's beta and the average market return.

Examples

Run this code
# NOT RUN {
jenson.alpha(funds$ret1, funds$rfr)
# }

Run the code above in your browser using DataLab