Learn R Programming

rportfolio (version 0.0.3)

ratio.information: Information Ratio

Description

Calculates the information ratio of the portfolio

Usage

ratio.information(R1, R2)

Arguments

R1

Returns of the portfolio

R2

Returns of the benchmark portfolio

Value

Calculates the information ratio of the portfolio

Details

The information ratio (IR) is a measurement of portfolio returns beyond the returns of a benchmark, usually an index, compared to the volatility of those returns.

Examples

Run this code
# NOT RUN {
ratio.information(funds$ret1, funds$rfr)
# }

Run the code above in your browser using DataLab