Learn R Programming

rportfolio (version 0.0.3)

ratio.sharpe: Sharpe Ratio

Description

Calculates the Sharpe Ratio of the Portfolio

Usage

ratio.sharpe(R1, Rf = 0)

Arguments

R1

Portfolio Returns

Rf

Risk Free Rate of Return, Default: 0

Value

Calculates the Sharpe Ratio of the portfolio

Details

The Sharpe ratio was developed by Nobel laureate William F. Sharpe and is used to help investors understand the return of an investment compared to its risk.