Learn R Programming

rportfolio (version 0.0.3)

ratio.sortino: Sortino Ratio

Description

Calculates the Sortino Ratio

Usage

ratio.sortino(R1, Rf = 0)

Arguments

R1

Returns of the portfolio

Rf

Risk Free rate of return, Default: 0

Value

Gives the Sortino ratio of the portfolio

Details

The Sortino ratio is a variation of the Sharpe ratio that differentiates harmful volatility from total overall volatility by using the asset's standard deviation of negative portfolio returns, called downside deviation, instead of the total standard deviation of portfolio returns.

Examples

Run this code
# NOT RUN {
ratio.sortino(funds$ret)
# }

Run the code above in your browser using DataLab