Learn R Programming

rportfolio (version 0.0.3)

ratio.treynor: Treynor Ratio

Description

Calculates the Treynor ratio of a particular portfolio

Usage

ratio.treynor(R1, Rf = 0)

Arguments

R1

Returns of the portfolio

Rf

Returns of the benchmark portfolio

Value

This function can be used to calculate the Treynor ratio of a portfolio.

Details

The Treynor ratio, also known as the reward-to-volatility ratio, is a performance metric for determining how much excess return was generated for each unit of risk taken on by a portfolio.

Examples

Run this code
# NOT RUN {
ratio.treynor(funds$ret1)
# }

Run the code above in your browser using DataLab