Learn R Programming

rportfolio (version 0.0.3)

returns.cal: Annualized Returns

Description

Returns the annualized returns of a data returns data

Usage

returns.cal(R1, freq = 252, geometric = TRUE)

Arguments

R1

Returns dataset as xts

freq

The periodicity of the dataset, Default: 252

geometric

Boolean to control the geometric returns and mean annualized returns, Default: TRUE

Value

Gives annualized returns of data

Details

An annualized total return is the geometric average amount of money earned by an investment each year over a given time period.

Examples

Run this code
# NOT RUN {
returns.cal(funds$ret1)
# }

Run the code above in your browser using DataLab