Learn R Programming

rportfolio (version 0.0.3)

risk.premium: Risk Premium of a Security

Description

This function is used to calculate the risk premium of excess return over the risk free rate

Usage

risk.premium(R1, Rf)

Arguments

R1

The returns of the security as xts

Rf

The risk free rate of return as xts

Value

Returns the risk premium of the security

Details

A risk premium is the return in excess of the risk-free rate of return an investment is expected to yield

Examples

Run this code
# NOT RUN {
risk.premium(funds$ret1, funds$rfr)
# }

Run the code above in your browser using DataLab