Alpha is a term used in investing to describe a strategy's ability to beat the market, or it's "edge." Alpha is thus also often referred to as <U+201C>excess return<U+201D> or <U+201C>abnormal rate of return,<U+201D> which refers to the idea that markets are efficient, and so there is no way to systematically earn returns that exceed the broad market as a whole.