powered by
Calculates the information ratio of the portfolio
ratio.information(R1, R2)
Returns of the portfolio
Returns of the benchmark portfolio
The information ratio (IR) is a measurement of portfolio returns beyond the returns of a benchmark, usually an index, compared to the volatility of those returns.
# NOT RUN { ratio.information(funds$ret1, funds$rfr) # }
Run the code above in your browser using DataLab