Calculates the Treynor ratio of a particular portfolio
Usage
ratio.treynor(R1, Rf = 0)
Arguments
R1
Returns of the portfolio
Rf
Returns of the benchmark portfolio
Value
This function can be used to calculate the Treynor ratio of a portfolio.
Details
The Treynor ratio, also known as the reward-to-volatility ratio, is a performance metric for determining how much excess return was generated for each unit of risk taken on by a portfolio.