powered by
Returns the annualized returns of a data returns data
returns.cal(R1, freq = 252, geometric = TRUE)
Returns dataset as xts
The periodicity of the dataset, Default: 252
Boolean to control the geometric returns and mean annualized returns, Default: TRUE
Gives annualized returns of data
An annualized total return is the geometric average amount of money earned by an investment each year over a given time period.
# NOT RUN { returns.cal(funds$ret1) # }
Run the code above in your browser using DataLab