powered by
This function is used to calculate the risk premium of excess return over the risk free rate
risk.premium(R1, Rf)
The returns of the security as xts
The risk free rate of return as xts
Returns the risk premium of the security
A risk premium is the return in excess of the risk-free rate of return an investment is expected to yield
# NOT RUN { risk.premium(funds$ret1, funds$rfr) # }
Run the code above in your browser using DataLab